@@ -97,7 +97,7 @@ NumericMatrix solvearma(const NumericMatrix X) {
 
 //[[Rcpp::export]]
 NumericMatrix sim_thetacpp(int S, NumericVector lambda, int n_sources, 
-                           int n_tracers){
+                           int n_tracers, bool solo){
   NumericMatrix theta(S, (n_sources + n_tracers));
   
   NumericVector mean(n_sources);
@@ -129,13 +129,21 @@ NumericMatrix sim_thetacpp(int S, NumericVector lambda, int n_sources,
   
   normmat = rMVNormCpp(S, mean, chol_prec);
   
+  NumericVector solovec(S);
   
-  
-  for(int i = 0; i<n_tracers; i++){
-    theta(_,i+n_sources) = Rcpp::rgamma(S,  lambda((n_sources + (n_sources * (n_sources + 1)) / 2) + i),
-          1/lambda(((n_sources + (n_sources * (n_sources + 1)) / 2)) + n_tracers + i));
+  for(int s = 0; s<S; s++){
+    solovec(s) = 1000;
   }
   
+  if(solo == FALSE) for(int i = 0; i<n_tracers; i++){
+    theta(_,i+n_sources) = Rcpp::rgamma(S,  lambda((n_sources + (n_sources * (n_sources + 1)) / 2) + i),
+          1/lambda(((n_sources + (n_sources * (n_sources + 1)) / 2)) + n_tracers + i));}
+   else if(solo == TRUE) for(int i = 0; i<n_tracers; i++){
+      theta(_,i+n_sources) = solovec + 0.00001 * Rcpp::rgamma(S,  lambda((n_sources + (n_sources * (n_sources + 1)) / 2) + i),
+            1/lambda(((n_sources + (n_sources * (n_sources + 1)) / 2)) + n_tracers + i));;
+    }
+  
+  
   
   for(int i=0; i<n_sources; i++){
     theta(_,i) = normmat(_,i);
@@ -208,7 +216,7 @@ double hcpp(int n_sources, int n_isotopes,
   }
   
   for (int i = 0; i<n_isotopes; i++){
-    c_0(i) = 0.001;
+    c_0(i) = 1;
     d_0(i) = beta_prior;
   }
   
@@ -364,7 +372,8 @@ double hcpp(int n_sources, int n_isotopes,
   
   double gammaprior = 0;
   for (int i=0; i <(n_isotopes); i++){
-    gammaprior += c_0(i) * log(d_0(i)) - log(tgamma(c_0(i))) +(c_0(i) - 1) * theta((i+n_sources)) -
+    //theta should be log_theta?? I think
+    gammaprior += c_0(i) * log(d_0(i)) - log(tgamma(c_0(i))) +(c_0(i) - 1) *theta((i+n_sources)) -
       d_0(i) * theta((i+n_sources));
     
   }
@@ -766,7 +775,8 @@ NumericVector run_VB_cpp(NumericVector lambdastart,
                          double beta_2,
                          int tau,
                          double eps_0,
-                         int t_W
+                         int t_W,
+                         bool solo
 ){
   
  
@@ -775,7 +785,7 @@ NumericVector run_VB_cpp(NumericVector lambdastart,
   
   NumericMatrix theta(S, (n_sources + n_tracers));
   
-  theta = sim_thetacpp(S, lambdastart, n_sources, n_tracers);
+  theta = sim_thetacpp(S, lambdastart, n_sources, n_tracers, solo);
   
   NumericVector c(lsl);
   
@@ -833,7 +843,7 @@ NumericVector run_VB_cpp(NumericVector lambdastart,
   
   while(stop == FALSE){
     
-    theta = sim_thetacpp(S, lambda, n_sources, n_tracers);
+    theta = sim_thetacpp(S, lambda, n_sources, n_tracers, solo);
     
     g_t = nabla_LB_cpp(lambda, theta, n_sources, n_tracers, beta_prior, concentrationmeans,
                        sourcemeans, correctionmeans, corrsds, sourcesds,
